@@ -6,7 +6,7 @@ use warnings;
 	package Ask;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.011';
+	our $VERSION   = '0.012';
 	
 	use Carp qw(croak);
 	use Moo::Role qw();
@@ -33,14 +33,18 @@ use warnings;
 		__plugins(@_);
 	}
 	
+	sub backends {
+		my $class  = shift;
+		sort { $b->quality <=> $a->quality }
+			grep { eval { use_package_optimistically($_)->DOES('Ask::API') } }
+			$class->plugins;
+	}
+	
 	sub detect {
 		my $class  = shift;
 		my %args   = @_==1 ? %{$_[0]} : @_;
 		
-		my @implementations =
-			sort { $b->quality <=> $a->quality }
-			grep { eval { use_package_optimistically($_)->DOES('Ask::API') } }
-			$class->plugins;
+		my @implementations = $class->backends;
 		
 		if (exists $ENV{PERL_ASK_BACKEND}) {
 			@implementations = use_module($ENV{PERL_ASK_BACKEND});
@@ -52,7 +56,7 @@ use warnings;
 		my @traits = @{ delete($args{traits}) || [] };
 		for my $i (@implementations) {
 			my $k = @traits ? "Moo::Role"->create_class_with_roles($i, @traits) : $i;
-			my $self = eval { $k->new(\%args) } or next;
+			my $self = eval { $k->new({ %args, %{ $args{$i} or {} } }) } or next;
 			return $self if $self->is_usable;
 		}
 		
@@ -96,7 +100,7 @@ what sets C<Ask> apart from them is that C<Ask> will detect how your script
 is being run (in a terminal, headless, etc) and choose an appropriate way
 to interact with the user.
 
-=head2 Class Method
+=head2 Class Methods
 
 =over
 
@@ -105,6 +109,14 @@ to interact with the user.
 A constructor, sort of. It inspects the program's environment and returns an
 object that implements the Ask API (see below).
 
+Backend-specific arguments can be provided:
+
+  my $ask = Ask->detect(
+    %common_args,
+    'Ask::STDIO'  => \%stdio_args,
+    'Ask::Zenity' => \%zenity_args,
+  );
+
 Note that these objects don't usually inherit from C<Ask>, so the following
 will typically be false:
 
@@ -116,6 +128,22 @@ Instead, check:
    my $ask = Ask->detect(%arguments);
    $ask->DOES("Ask::API");
 
+=item C<< Ask->backends >>
+
+Returns a list of available backends. Each backend is a Perl class name. Some
+of the backends may be available (i.e. installed and able to be compiled)
+without being usable under current circumstances (e.g. the Gtk2 backend is
+available but cannot be used because no X server is running). To check
+usability, instantiate the class and call C<is_usable> on the instance.
+
+The list is sorted in "quality" order, best to worst, though quality is
+subjective.
+
+=item C<< Ask->plugins >>
+
+The same as C<< Ask->backends >>, but doesn't check that each result is a
+loadable Perl class, and doesn't sort them in any particular order.
+
 =back
 
 =head2 The Ask API
@@ -194,6 +222,9 @@ The C<default> argument can be used to supply a default return value if the
 user cannot be asked for some reason (e.g. running on an unattended terminal).
 If C<multiple> is true, then this must be an arrayref.
 
+Until version 0.011, returned values are strings. Thereafter, returned values
+are L<Path::Tiny> objects.
+
 =item C<< single_choice(text => $text, choices => \@choices) >>
 
 Asks the user to select a single option from many choices.
@@ -316,19 +347,27 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Ask>.
 
 =head1 SEE ALSO
 
-See L<Ask::API> for documentation of API internals.
-
-Bundled Ask API backends:
+Terminal backends:
 
 =over
 
 =item *
 
-L<Ask::Callback> - implementation for testing; redirects input and output to callback functions.
+L<Ask::STDIO> - very basic usage of STDIN/STDOUT/STDERR
 
 =item *
 
-L<Ask::Fallback> - returns default answers; for scripts running unattended.
+L<Ask::Caroline> - uses L<Caroline> and L<Term::ANSIColor> for better interaction
+
+=item *
+
+L<Ask::Clui> - uses L<Term::Clui> for better interaction
+
+=back
+
+GUI backends:
+
+=over
 
 =item *
 
@@ -336,7 +375,7 @@ L<Ask::Gtk> - GUI using L<Gtk2>.
 
 =item *
 
-L<Ask::STDIO> - based on STDIN/STDOUT/STDERR
+L<Ask::Prima> - GUI using L<Prima>.
 
 =item *
 
@@ -352,6 +391,24 @@ L<Ask::Zenity> - GUI using the C<< /usr/bin/zenity >> binary (part of GNOME)
 
 =back
 
+Backends which perform no real user interaction:
+
+=over
+
+=item *
+
+L<Ask::Callback> - implementation for testing; redirects input and output to callback functions.
+
+=item *
+
+L<Ask::Fallback> - returns default answers; for scripts running unattended.
+
+=back
+
+See L<Ask::API> for documentation of API internals.
+
+See L<Ask::Question> for an alternative way of using Ask.
+
 Similar modules: L<IO::Prompt>, L<IO::Prompt::Tiny> and many others.
 
 =head1 AUTHOR
