@@ -6,10 +6,11 @@ use warnings;
 	package Ask::Fallback;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.011';
+	our $VERSION   = '0.012';
 	
 	use Moo;
 	use Carp qw(croak);
+	use Path::Tiny qw(path);
 	use namespace::autoclean;
 	
 	with 'Ask::API';
@@ -50,8 +51,8 @@ use warnings;
 	sub file_selection
 	{
 		my ($self, %o) = @_;
-		$o{multiple} and exists $o{default} and return @{$o{default}};
-		exists $o{default} and return $o{default};
+		$o{multiple} and exists $o{default} and return map path($_), @{$o{default}};
+		exists $o{default} and return path $o{default};
 		croak "file_selection (Ask::Fallback) with no default";
 	}
 	
