@@ -6,7 +6,7 @@ use warnings;
 	package Ask::STDIO;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.011';
+	our $VERSION   = '0.012';
 	
 	use Moo;
 	use namespace::autoclean;
@@ -25,9 +25,10 @@ use warnings;
 	sub entry {
 		my ($self, %o) = @_;
 		$self->info(text => $o{text}) if exists $o{text};
-		my $line;
 		
-		if ($o{hide_text}) {
+		my ( $line, $tio );
+		
+		if ( $o{hide_text} and do { require POSIX; $tio = 'POSIX::Termios'->new } ) {
 			require POSIX;
 			my $tio = POSIX::Termios->new;
 			$tio->getattr(0);
