@@ -6,11 +6,12 @@ use warnings;
 	package Ask::Zenity;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.011';
+	our $VERSION   = '0.012';
 	
 	use Moo;
 	use File::Which qw(which);
 	use System::Command;
+	use Path::Tiny qw( path );
 	use namespace::autoclean;
 	
 	has zenity_path => (
@@ -86,7 +87,8 @@ use warnings;
 		my $self = shift;
 		my $text = readline($self->_zenity(file_selection => @_)->stdout);
 		chomp $text;
-		return split m#[|]#, $text;
+		my @files = map path($_), split m#[|]#, $text;
+		@files == 1 ? $files[0] : @files;
 	}
 	
 	sub single_choice {
@@ -131,7 +133,7 @@ __END__
 
 =head1 NAME
 
-Ask::Zenity - use C<< /usr/bin/zenity >> to interact with a user
+Ask::Zenity - use /usr/bin/zenity to interact with a user
 
 =head1 SYNOPSIS
 
